@@ -1,7 +1,7 @@
 const flexSpec = require('./flex-spec');
 const Declaration = require('../declaration');
 
-const list = require('postcss/lib/list');
+const list = require('postcss').list;
 
 class Flex extends Declaration {
 
